==> huaweicloudsdkdrs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_health_object_compare_job_overview_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHealthObjectCompareJobOverviewResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'compare_result': 'list[ObjectsHealthCompareOverviewInfo]'
    }

    attribute_map = {
        'compare_result': 'compare_result'
    }

    def __init__(self, compare_result=None):
        """ShowHealthObjectCompareJobOverviewResponse

        The model defined in huaweicloud sdk

        :param compare_result: 健康对比对象级对比结果。
        :type compare_result: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        
        super(ShowHealthObjectCompareJobOverviewResponse, self).__init__()

        self._compare_result = None
        self.discriminator = None

        if compare_result is not None:
            self.compare_result = compare_result

    @property
    def compare_result(self):
        """Gets the compare_result of this ShowHealthObjectCompareJobOverviewResponse.

        健康对比对象级对比结果。

        :return: The compare_result of this ShowHealthObjectCompareJobOverviewResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        return self._compare_result

    @compare_result.setter
    def compare_result(self, compare_result):
        """Sets the compare_result of this ShowHealthObjectCompareJobOverviewResponse.

        健康对比对象级对比结果。

        :param compare_result: The compare_result of this ShowHealthObjectCompareJobOverviewResponse.
        :type compare_result: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        self._compare_result = compare_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHealthObjectCompareJobOverviewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.152-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/show_health_object_compare_job_overview_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowHealthObjectCompareJobOverviewResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'compare_result': 'list[ObjectsHealthCompareOverviewInfo]'
    }

    attribute_map = {
        'compare_result': 'compare_result'
    }

    def __init__(self, compare_result=None):
        r"""ShowHealthObjectCompareJobOverviewResponse

        The model defined in huaweicloud sdk

        :param compare_result: 健康对比对象级对比结果。
        :type compare_result: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        
        super(ShowHealthObjectCompareJobOverviewResponse, self).__init__()

        self._compare_result = None
        self.discriminator = None

        if compare_result is not None:
            self.compare_result = compare_result

    @property
    def compare_result(self):
        r"""Gets the compare_result of this ShowHealthObjectCompareJobOverviewResponse.

        健康对比对象级对比结果。

        :return: The compare_result of this ShowHealthObjectCompareJobOverviewResponse.
        :rtype: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        return self._compare_result

    @compare_result.setter
    def compare_result(self, compare_result):
        r"""Sets the compare_result of this ShowHealthObjectCompareJobOverviewResponse.

        健康对比对象级对比结果。

        :param compare_result: The compare_result of this ShowHealthObjectCompareJobOverviewResponse.
        :type compare_result: list[:class:`huaweicloudsdkdrs.v5.ObjectsHealthCompareOverviewInfo`]
        """
        self._compare_result = compare_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowHealthObjectCompareJobOverviewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
